==> ameba-0.61.tar.bz2: ameba-0.61/actions.h <==
#ifndef _ACTION_H
#define _ACTION_H

#include <pthread.h>
#include <client_handler.h>
#include "object.h"

class Druid;

class Background {
    static const int max_count = 3;
    Druid& act;
    double displace;
    double last;
    double period;
    double maximal;
    double same;
    double value;
    unsigned int errcount;
public:
    Background( Config&, Druid& );
    bool run_checked();
    bool run_nochecked();
    bool no_needed();
    bool needed();
    double get() { return value; }
private:
    double measure();
};

class Druid {
    static const int max_attempts = 8;
    static const int max_retries = 2;
    std::auto_ptr<ClientHandler> dimm;
    std::auto_ptr<ClientHandler> mass;
    std::auto_ptr<ClientHandler> tlsp;
    Background background;
    unsigned int settle_time;
    unsigned int errcount;
    double focus;
    double separation;
    double sep_tolrn;
    double work_zone;
    double mass_mag_ext;
    double star_flux_d;
    unsigned int errflux;
    std::vector<double> mass_mag_set;
    friend class Background;
    bool mass_enable;
    double guide_last;
public:
    Druid( Config& );
    ~Druid();
    bool point_star( const ObjectInfo& );
    bool check_star( const ObjectInfo& );
    bool check_status( const ObjectInfo& );
    bool no_check_status( const ObjectInfo& );
    bool check_background( const ObjectInfo& );
    bool check_flux();
    bool measurement();
    bool dimm_measurement();
    bool beginning();
    bool photo_stability();
    void regime( const std::string& );
private:
    bool center_star(  const ObjectInfo& );
    bool init();
    bool park( ClientHandler* );
    void focusing( double );
    bool focus_dimm();
    double check_separation();
    bool stop_guiding();
    bool start_guiding();
    bool start_dimm_guiding();
    bool check_mass_mag( const ObjectInfo&, double );
    void camera( const std::string& );
};

#endif

==> ameba-0.62.tar.bz2: ameba-0.62/actions.h <==
#ifndef _ACTION_H
#define _ACTION_H

#include <pthread.h>
#include <client_handler.h>
#include "object.h"

class Druid;

class Background {
    static const int max_count = 3;
    Druid& act;
    double displace;
    double last;
    double period;
    double maximal;
    double same;
    double value;
    unsigned int errcount;
public:
    Background( Config&, Druid& );
    bool run_checked();
    bool run_nochecked();
    bool no_needed();
    bool needed();
    double get() { return value; }
private:
    double measure();
};

class Druid {
    static const int max_attempts = 8;
    static const int max_retries = 2;
    std::auto_ptr<ClientHandler> dimm;
    std::auto_ptr<ClientHandler> mass;
    std::auto_ptr<ClientHandler> tlsp;
    Background background;
    unsigned int settle_time;
    unsigned int errcount;
    double focus;
    double separation;
    double sep_tolrn;
    double work_zone;
    double mass_mag_ext;
    double star_flux_d;
    unsigned int errflux;
    std::vector<double> mass_mag_set;
    friend class Background;
    bool mass_enable;
    bool cnt_on;
    double guide_last;
public:
    Druid( Config& );
    ~Druid();
    bool point_star( const ObjectInfo& );
    bool check_star( const ObjectInfo& );
    bool check_status( const ObjectInfo& );
    bool no_check_status( const ObjectInfo& );
    bool check_background( const ObjectInfo& );
    bool check_flux();
    bool measurement();
    bool dimm_measurement();
    bool beginning();
    bool photo_stability( unsigned int );
    bool cnt( bool );
    void regime( const std::string& );
private:
    bool center_star(  const ObjectInfo& );
    bool init();
    bool park( ClientHandler* );
    void focusing( double );
    bool focus_dimm();
    double check_separation();
    bool stop_guiding();
    bool start_guiding();
    bool start_dimm_guiding();
    bool check_mass_mag( const ObjectInfo&, double );
    void camera( const std::string& );
};

#endif
